pytilities.event — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »

# pytilities.event

Delegation utilities

Classes:

> Dispatcher
>   Utility class for dispatching events to handlers.
> DispatcherSwitch
>   Provides a single interface to multiple event dispatchers.
> RestrictedDispatcher
>   Dispatcher wrapper that filters the list of supported events.

Contents

- Dispatcher
- DispatcherSwitch
- RestrictedDispatcher

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »
- API documentation »
- pytilities »